@@ -114,7 +114,7 @@ fn make() -> &'static str {
 }
 
 fn run(cmd: &mut Command) {
-    println!("running: {}", cmd);
+    println!("running: {:?}", cmd);
     assert!(cmd.stdout(InheritFd(1))
                .stderr(InheritFd(2))
                .status()
